@@ -142,10 +142,14 @@ repository = %(repository_path)s
           process_group_pid_list=process_group_pid_list)
         if run_software:
           # this should be always true later, but it is too slow for now
-          slapos_controler.runSoftwareRelease(config,
+          status_dict = slapos_controler.runSoftwareRelease(config,
             environment=config['environment'],
             process_group_pid_list=process_group_pid_list,
             )
+          if status_dict['status_code'] != 0:
+            safeRpcCall(master.reportTaskFailure,
+              test_result, status_dict, config['computer_id'])
+            continue
           run_software = False
 
         # create instances, it should take some seconds only
